 package com.supermap.samplecode.mapping;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Frame;

import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;

import com.supermap.data.Workspace;
import com.supermap.ui.MapControl;

 /**
  * <p>
  * Title:统一风格标签专题图
  * Title:label map with uniformstyl
  * </p>
  * 
  * <p>
  * Description:
  * ============================================================================>
  * ------------------------------版权声明----------------------------
  * 此文件为SuperMap Objects Java 的示范代码 
  * 版权所有：北京超图软件股份有限公司
  * ----------------------------------------------------------------
  *------------------------------Copyright Statement----------------------------
  *
  * This is the Sample Code of SuperMap iObjects Java 
  * SuperMap Software Co., Ltd. All Rights Reserved. 
  *------------------------------------------------------------------
  * ---------------------SuperMap iObjects Java 示范程序说明------------------------
  * 
  * 1、范例简介：创建统一风格标签专题图
  * 2、示例数据：安装目录\SampleData\ThematicMaps\Thematicmaps.smwu;
  * 3、关键类型/成员: 
  *      ThemeLabel.setUniformStyle 方法
  *      ThemeLabel.setLabelExpression 方法
  *      TextStyle.setForeColor 方法
  *      TextStyle.setBackColor 方法
  *      TextStyle.setBold 方法
  *      TextStyle.setOutline 方法
  *      TextStyle.setFontHeight 方法
  * 4、使用步骤：
  *  (1)勾选多选框创建统一风格标签专题图，取消勾选移除统一风格标签专题图
  * ------------------------------------------------------------------------------
  *-----------------------The description of SuperMap iObjects Java Sample Code --------------------------
  *
  *1.Sample Code Description:This sample demonstrates how to make the label map with uniformstyle. 
  *2.Sample Data:Installation directory\SampleData\ThematicMaps\ThematicMaps.smwu
  *3.Key Classes/Methods: 
  *      ThemeLabel.setUniformStyle Method
  *      ThemeLabel.setLabelExpression Method
  *      TextStyle.setForeColor Method
  *      TextStyle.setBackColor Method
  *      TextStyle.setBold Method
  *      TextStyle.setOutline Method
  *      TextStyle.setFontHeight Method 
  *4.Procedures:
  *  (1)Browse the theme map
  *  (2)Whether to display the theme layer or not can be controlled by the CheckBox 
  *---------------------------------------------------------------------------------------
  * ============================================================================>
  * </p> 
  * 
  * <p>
  * Company: 北京超图软件股份有限公司
  * Company: SuperMap Software Co., Ltd
  * </p>
  * 
  */

public class MainFrame extends JFrame {

	private static final long serialVersionUID = 1L;
	
	private Workspace m_workspace;

	private MapControl m_mapControl;
	
	private SampleRun m_sampleRun;

	private JPanel m_contentPane;

	private JPanel m_panelToolBar;

	private JCheckBox m_CheckBoxUniformStyleThemeLabel;

	/**
	 * 初始化工具栏
	 * Initialize the toolbar
	 * 	
	 */
	private JPanel getToolBar() {
		if (m_panelToolBar == null) {
			FlowLayout flowLayout = new FlowLayout();
			flowLayout.setAlignment(FlowLayout.LEFT);
			m_panelToolBar = new JPanel();
			m_panelToolBar.setLayout(flowLayout);
			m_panelToolBar.add(getCheckBoxUniformStyleThemeLabel(), null);
		}
		return m_panelToolBar;
	}

	/**
	 * 获取m_CheckBoxUniformStyleThemeLabel
	 * Get m_CheckBoxUniformStyleThemeLabel
	 */
	private JCheckBox getCheckBoxUniformStyleThemeLabel() {
		if (m_CheckBoxUniformStyleThemeLabel == null) {
			m_CheckBoxUniformStyleThemeLabel = new JCheckBox();
			m_CheckBoxUniformStyleThemeLabel.setSelected(true);
			m_CheckBoxUniformStyleThemeLabel.setText(getText("m_CheckBoxUniformStyleThemeLabel"));
			m_CheckBoxUniformStyleThemeLabel.addItemListener(new java.awt.event.ItemListener() {
				public void itemStateChanged(java.awt.event.ItemEvent e) {
					m_sampleRun.makeUniformStyleThemeLabel(m_CheckBoxUniformStyleThemeLabel.isSelected());
				}
			});
		}
		return m_CheckBoxUniformStyleThemeLabel;
	}

	/**
	 * 程序入口点
	 * Main entry of the program
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame thisClass = new MainFrame();
				thisClass.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				thisClass.setVisible(true);
			}
		});
	}

	/**
	 * 构造函数
	 * Constructor
	 */
	public MainFrame() {
		super();
		initialize();
	}

	/**
	 * 初始化窗体
	 * Initialize the form
	 */
	private void initialize() {
		// 最大化显示窗体
		// Maximize the form
		this.setExtendedState(Frame.MAXIMIZED_BOTH);
		this.setSize(768, 564);
		this.setTitle(getText("this"));
		this.setContentPane(getJContentPane());
		this.addWindowListener(new java.awt.event.WindowAdapter() {
			// 在主窗体加载时，初始化SampleRun类型，来完成功能的展现
			// Initialize the SampleRun type when loading the main form
			public void windowOpened(java.awt.event.WindowEvent e) {
				m_workspace = new Workspace();
				m_sampleRun = new SampleRun(m_workspace, m_mapControl);
			}

			// 在窗体关闭时，需要释放相关的资源
			// Release the relvant resources when closing the form
			public void windowClosing(java.awt.event.WindowEvent e) {
				m_mapControl.dispose();
				m_workspace.dispose();
			}
		});		
	}

	/**
	 * 获取m_contentPane
	 * Get m_contentPane
	 */
	private JPanel getJContentPane() {
		if (m_contentPane == null) {
			m_contentPane = new JPanel();
			m_contentPane.setLayout(new BorderLayout());
			m_contentPane.add(getToolBar(), BorderLayout.NORTH);
			m_contentPane.add(getMapControl(), BorderLayout.CENTER);
		}
		return m_contentPane;
	}
	
	/**
	 * 构建MapControl控件
	 * Build MapControl
	 */
	private MapControl getMapControl() {
		if (m_mapControl == null) {
			m_mapControl = new MapControl();			
		}
		return m_mapControl;
	}
	
    private String getText(String id)
	{
		String text = "";
		if (com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "m_CheckBoxUniformStyleThemeLabel")
			{
				text = "统一风格标签专题图";
			}
			if(id == "this")
			{
				text = "统一风格标签专题图";
			}
		}
		else
		{
			if(id == "m_CheckBoxUniformStyleThemeLabel")
			{
				text = " UnifromStyle Label Map";
			}
			if(id == "this")
			{
				text = " UnifromStyle Label Map";
			}
		}
		return text;
	}

}

