package com.supermap.samplecode.mapping;


import java.awt.Color;

import com.supermap.data.DatasetVector;
import com.supermap.data.TextStyle;
import com.supermap.data.Workspace;
import com.supermap.data.WorkspaceConnectionInfo;
import com.supermap.data.WorkspaceType;
import com.supermap.mapping.Layer;
import com.supermap.mapping.ThemeLabel;
import com.supermap.ui.MapControl;

/**
  * <p>
  * Title:统一风格标签专题图
  * Title:label map with uniformstyl
  * </p>
  * 
  * <p>
  * Description:
  * ============================================================================>
  * ------------------------------版权声明----------------------------
  * 此文件为SuperMap Objects Java 的示范代码 
  * 版权所有：北京超图软件股份有限公司
  * ----------------------------------------------------------------
  *------------------------------Copyright Statement----------------------------
  *
  * This is the Sample Code of SuperMap iObjects Java 
  * SuperMap Software Co., Ltd. All Rights Reserved. 
  *------------------------------------------------------------------
  * ---------------------SuperMap iObjects Java 示范程序说明------------------------
  * 
  * 1、范例简介：创建统一风格标签专题图
  * 2、示例数据：安装目录\SampleData\ThematicMaps\Thematicmaps.smwu;
  * 3、关键类型/成员: 
  *      ThemeLabel.setUniformStyle 方法
  *      ThemeLabel.setLabelExpression 方法
  *      TextStyle.setForeColor 方法
  *      TextStyle.setBackColor 方法
  *      TextStyle.setBold 方法
  *      TextStyle.setOutline 方法
  *      TextStyle.setFontHeight 方法
  * 4、使用步骤：
  *  (1)勾选多选框创建统一风格标签专题图，取消勾选移除统一风格标签专题图
  * ------------------------------------------------------------------------------
  *-----------------------The description of SuperMap iObjects Java Sample Code --------------------------
  *
  *1.Sample Code Description:This sample demonstrates how to make the label map with uniformstyle. 
  *2.Sample Data:Installation directory\SampleData\ThematicMaps\ThematicMaps.smwu
  *3.Key Classes/Methods: 
  *      ThemeLabel.setUniformStyle Method
  *      ThemeLabel.setLabelExpression Method
  *      TextStyle.setForeColor Method
  *      TextStyle.setBackColor Method
  *      TextStyle.setBold Method
  *      TextStyle.setOutline Method
  *      TextStyle.setFontHeight Method 
  *4.Procedures:
  *  (1)Browse the theme map
  *  (2)Whether to display the theme layer or not can be controlled by the CheckBox 
  *---------------------------------------------------------------------------------------
  * ============================================================================>
  * </p> 
  * 
  * <p>
  * Company: 北京超图软件股份有限公司
  * Company: SuperMap Software Co., Ltd
  * </p>
  * 
  */


public class SampleRun {
	
	private Workspace m_workspace;

	private DatasetVector dataset;
	
	private MapControl m_mapControl;
	
	Layer layer;

	/**
	 * 根据workspace, panel和mapControl构造 SampleRun对象
	 * Initialize the SampleRun object with the specified workspace and map
	 */
	public SampleRun(Workspace workspace, MapControl mapControl) {
		m_workspace = workspace;
		m_mapControl = mapControl;
		initialize();
	}

	/**
	 * 打开需要的工作空间文件及地图
	 * Open the workspace and the map
	 */
	private void initialize() {
		try {
			// 打开工作空间及地图
			// Open the workspace and the map
			WorkspaceConnectionInfo conInfo = new WorkspaceConnectionInfo(
			 "../../SampleData/ThematicMaps/Thematicmaps.smwu");
			conInfo.setType(WorkspaceType.SMWU);

			m_workspace.open(conInfo);
			dataset = (DatasetVector)m_workspace.getDatasources().get(0).getDatasets().get("BaseMap_R");
			m_mapControl.getMap().setWorkspace(m_workspace);
			Layer layer = m_mapControl.getMap().getLayers().add(dataset,true);
			layer.setSelectable(false);
			makeUniformStyleThemeLabel(true);
		} catch (Exception ex) {
			System.out.println(ex.getMessage());
		}
	}
	
	// 构建统一风格标签专题图
	// Make the uniform label map
	public void makeUniformStyleThemeLabel(boolean b)
	{
		if(!b)
		{
			m_mapControl.getMap().getLayers().remove(layer.getName());
		}
		else
		{
			ThemeLabel themeLabel = new ThemeLabel();
			TextStyle textStyle = new TextStyle();
			textStyle.setForeColor(new Color(0,0,0));
			textStyle.setBackColor(new Color(255,255,255));
			textStyle.setBold(true);
			textStyle.setOutline(true);
			textStyle.setFontHeight(4.5);
			themeLabel.setLabelExpression(getText("themeLabel"));
			// 设置统一风格
			// Set the UniformStyle value
			themeLabel.setUniformStyle(textStyle);
			layer = m_mapControl.getMap().getLayers().add(dataset, themeLabel, true);
		}
		
		m_mapControl.getMap().refresh();		
	}	
	
	private String getText(String id)
	{
		String text = "";
		if (com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "themeLabel")
			{
				text = "Name";
			}
		}
		else
		{
			if(id == "themeLabel")
			{
				text = "Name_en";
			}
		}
		return text;
	}
}

